# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteSpecification(BaseModel):
    delete_specification: Optional["DeleteSpecificationDeleteSpecification"] = Field(
        alias="deleteSpecification"
    )


class DeleteSpecificationDeleteSpecification(BaseModel):
    id: str
    state: EntityState


DeleteSpecification.model_rebuild()
