# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalProcedure(BaseModel):
    update_medical_procedure: Optional[
        "UpdateMedicalProcedureUpdateMedicalProcedure"
    ] = Field(alias="updateMedicalProcedure")


class UpdateMedicalProcedureUpdateMedicalProcedure(BaseModel):
    id: str
    name: str


UpdateMedicalProcedure.model_rebuild()
