# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalStudy(BaseModel):
    create_medical_study: Optional["CreateMedicalStudyCreateMedicalStudy"] = Field(
        alias="createMedicalStudy"
    )


class CreateMedicalStudyCreateMedicalStudy(BaseModel):
    id: str
    name: str


CreateMedicalStudy.model_rebuild()
