# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryRepos(BaseModel):
    repos: Optional["QueryReposRepos"]


class QueryReposRepos(BaseModel):
    results: Optional[List[Optional["QueryReposReposResults"]]]


class QueryReposReposResults(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    thing: Optional[str]
    relevance: Optional[float]


QueryRepos.model_rebuild()
QueryReposRepos.model_rebuild()
