# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteContent(BaseModel):
    delete_content: Optional["DeleteContentDeleteContent"] = Field(
        alias="deleteContent"
    )


class DeleteContentDeleteContent(BaseModel):
    id: str
    state: EntityState


DeleteContent.model_rebuild()
