# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreatePerson(BaseModel):
    create_person: Optional["CreatePersonCreatePerson"] = Field(alias="createPerson")


class CreatePersonCreatePerson(BaseModel):
    id: str
    name: str


CreatePerson.model_rebuild()
