# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateCategory(BaseModel):
    update_category: Optional["UpdateCategoryUpdateCategory"] = Field(
        alias="updateCategory"
    )


class UpdateCategoryUpdateCategory(BaseModel):
    id: str
    name: str


UpdateCategory.model_rebuild()
