# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteCollection(BaseModel):
    delete_collection: Optional["DeleteCollectionDeleteCollection"] = Field(
        alias="deleteCollection"
    )


class DeleteCollectionDeleteCollection(BaseModel):
    id: str
    state: EntityState


DeleteCollection.model_rebuild()
